# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.platform_limits_api import PlatformLimitsApi


class TestPlatformLimitsApi(unittest.TestCase):
    """PlatformLimitsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlatformLimitsApi()

    def tearDown(self) -> None:
        pass

    def test_create_platform_limit(self) -> None:
        """Test case for create_platform_limit

        Create Platform Limit
        """
        pass

    def test_delete_platform_limit(self) -> None:
        """Test case for delete_platform_limit

        Delete Platform Limit
        """
        pass

    def test_get_platform_limit(self) -> None:
        """Test case for get_platform_limit

        Get Platform Limit
        """
        pass

    def test_list_platform_limits(self) -> None:
        """Test case for list_platform_limits

        List Platform Limits
        """
        pass

    def test_update_platform_limit(self) -> None:
        """Test case for update_platform_limit

        Update Platform Limit
        """
        pass


if __name__ == '__main__':
    unittest.main()
