# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from wordlift_client.models.content_evaluation_response_quality_score_breakdown_seo_top_entities_value_inner import ContentEvaluationResponseQualityScoreBreakdownSeoTopEntitiesValueInner
from typing import Optional, Set
from typing_extensions import Self

class ContentEvaluationResponseQualityScoreBreakdownSeo(BaseModel):
    """
    ContentEvaluationResponseQualityScoreBreakdownSeo
    """ # noqa: E501
    keyword_density: Optional[Dict[str, Union[StrictFloat, StrictInt]]] = Field(description="Object with keyword percentages when keywords are provided")
    top_entities: Dict[str, List[ContentEvaluationResponseQualityScoreBreakdownSeoTopEntitiesValueInner]]
    score: StrictInt
    __properties: ClassVar[List[str]] = ["keyword_density", "top_entities", "score"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ContentEvaluationResponseQualityScoreBreakdownSeo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in top_entities (dict of array)
        _field_dict_of_array = {}
        if self.top_entities:
            for _key in self.top_entities:
                if self.top_entities[_key] is not None:
                    _field_dict_of_array[_key] = [
                        _item.to_dict() for _item in self.top_entities[_key]
                    ]
            _dict['top_entities'] = _field_dict_of_array
        # set to None if keyword_density (nullable) is None
        # and model_fields_set contains the field
        if self.keyword_density is None and "keyword_density" in self.model_fields_set:
            _dict['keyword_density'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ContentEvaluationResponseQualityScoreBreakdownSeo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "keyword_density": obj.get("keyword_density"),
            "top_entities": dict(
                (_k,
                        [ContentEvaluationResponseQualityScoreBreakdownSeoTopEntitiesValueInner.from_dict(_item) for _item in _v]
                        if _v is not None
                        else None
                )
                for _k, _v in obj.get("top_entities", {}).items()
            ),
            "score": obj.get("score")
        })
        return _obj


