# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.web_page_import_request import WebPageImportRequest

class TestWebPageImportRequest(unittest.TestCase):
    """WebPageImportRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WebPageImportRequest:
        """Test WebPageImportRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WebPageImportRequest`
        """
        model = WebPageImportRequest()
        if include_optional:
            return WebPageImportRequest(
                embedding = wordlift_client.models.embedding_request.EmbeddingRequest(
                    model = 'nomic-ai/nomic-embed-text-v1', 
                    properties = [
                        ''
                        ], ),
                id_generator = 'default',
                output_types = [
                    '["http://schema.org/WebPage"]'
                    ],
                url = ''
            )
        else:
            return WebPageImportRequest(
                url = '',
        )
        """

    def testWebPageImportRequest(self):
        """Test WebPageImportRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
