# coding: utf-8

"""
    Events

    An API to record and query events raised by clients in order to facilitate KPI tracking.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.account_google_search_console_api import AccountGoogleSearchConsoleApi


class TestAccountGoogleSearchConsoleApi(unittest.TestCase):
    """AccountGoogleSearchConsoleApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccountGoogleSearchConsoleApi()

    def tearDown(self) -> None:
        pass

    def test_update_account_config(self) -> None:
        """Test case for update_account_config

        Account configuration update
        """
        pass


if __name__ == '__main__':
    unittest.main()
