# coding: utf-8

"""
    Embeddings API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.search_analytics_synchronizations_api import SearchAnalyticsSynchronizationsApi


class TestSearchAnalyticsSynchronizationsApi(unittest.TestCase):
    """SearchAnalyticsSynchronizationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SearchAnalyticsSynchronizationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_sync1(self) -> None:
        """Test case for create_sync1

        Create analytics sync.
        """
        pass

    def test_list_analytics_syncs(self) -> None:
        """Test case for list_analytics_syncs

        Get the latest syncs
        """
        pass


if __name__ == '__main__':
    unittest.main()
