# coding: utf-8

"""
    Embeddings API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.image_to_text_api import ImageToTextApi


class TestImageToTextApi(unittest.TestCase):
    """ImageToTextApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ImageToTextApi()

    def tearDown(self) -> None:
        pass

    def test_image_to_text_api_image2_text_v1_post(self) -> None:
        """Test case for image_to_text_api_image2_text_v1_post

        Convert Image to Text
        """
        pass


if __name__ == '__main__':
    unittest.main()
