# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.web_page_import_response import WebPageImportResponse

class TestWebPageImportResponse(unittest.TestCase):
    """WebPageImportResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WebPageImportResponse:
        """Test WebPageImportResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WebPageImportResponse`
        """
        model = WebPageImportResponse()
        if include_optional:
            return WebPageImportResponse(
                model = '',
                web_page = wordlift_client.models.web_page.WebPage(
                    abstract = '', 
                    date_published = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    headline = '', 
                    html = '', 
                    image = '', 
                    markdown = '', 
                    text = '', 
                    types = [
                        ''
                        ], 
                    url = '', )
            )
        else:
            return WebPageImportResponse(
                model = '',
                web_page = wordlift_client.models.web_page.WebPage(
                    abstract = '', 
                    date_published = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    headline = '', 
                    html = '', 
                    image = '', 
                    markdown = '', 
                    text = '', 
                    types = [
                        ''
                        ], 
                    url = '', ),
        )
        """

    def testWebPageImportResponse(self):
        """Test WebPageImportResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
