# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.account_info import AccountInfo

class TestAccountInfo(unittest.TestCase):
    """AccountInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccountInfo:
        """Test AccountInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AccountInfo`
        """
        model = AccountInfo()
        if include_optional:
            return AccountInfo(
                account_id = 56,
                dataset_id = '',
                dataset_uri = '',
                features = {
                    'key' : True
                    },
                google_search_console_site_url = '',
                key = '',
                language = '',
                networks = [
                    wordlift_client.models.network_account_info.NetworkAccountInfo(
                        account_id = 56, 
                        dataset_id = '', 
                        dataset_uri = '', 
                        url = '', )
                    ],
                ng_dataset_id = '',
                subscription_id = 56,
                url = '',
                wp_admin = '',
                wp_json = ''
            )
        else:
            return AccountInfo(
                account_id = 56,
                dataset_uri = '',
                networks = [
                    wordlift_client.models.network_account_info.NetworkAccountInfo(
                        account_id = 56, 
                        dataset_id = '', 
                        dataset_uri = '', 
                        url = '', )
                    ],
                subscription_id = 56,
        )
        """

    def testAccountInfo(self):
        """Test AccountInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
