# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.questions_and_answers_api import QuestionsAndAnswersApi


class TestQuestionsAndAnswersApi(unittest.TestCase):
    """QuestionsAndAnswersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = QuestionsAndAnswersApi()

    def tearDown(self) -> None:
        pass

    def test_create_question_and_answer(self) -> None:
        """Test case for create_question_and_answer

        Create
        """
        pass

    def test_create_questions_and_answers_collection(self) -> None:
        """Test case for create_questions_and_answers_collection

        Create
        """
        pass

    def test_delete_question_and_answer(self) -> None:
        """Test case for delete_question_and_answer

        Delete
        """
        pass

    def test_delete_questions_and_answers_collection(self) -> None:
        """Test case for delete_questions_and_answers_collection

        Delete
        """
        pass

    def test_get_questions_and_answers(self) -> None:
        """Test case for get_questions_and_answers

        Get
        """
        pass

    def test_update_question_and_answer(self) -> None:
        """Test case for update_question_and_answer

        Update
        """
        pass

    def test_update_questions_and_answers_collection(self) -> None:
        """Test case for update_questions_and_answers_collection

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()
