# coding: utf-8

"""
    Embeddings API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.content_evaluation_response_quality_score_breakdown_seo import ContentEvaluationResponseQualityScoreBreakdownSeo

class TestContentEvaluationResponseQualityScoreBreakdownSeo(unittest.TestCase):
    """ContentEvaluationResponseQualityScoreBreakdownSeo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ContentEvaluationResponseQualityScoreBreakdownSeo:
        """Test ContentEvaluationResponseQualityScoreBreakdownSeo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ContentEvaluationResponseQualityScoreBreakdownSeo`
        """
        model = ContentEvaluationResponseQualityScoreBreakdownSeo()
        if include_optional:
            return ContentEvaluationResponseQualityScoreBreakdownSeo(
                keyword_density = {
                    'key' : 1.337
                    },
                top_entities = {
                    'key' : [
                        wordlift_client.models.content_evaluation_response_quality_score_breakdown_seo_top_entities_value_inner.ContentEvaluationResponse_quality_score_breakdown_seo_top_entities_value_inner(
                            text = '', 
                            count = 56, )
                        ]
                    },
                score = 56
            )
        else:
            return ContentEvaluationResponseQualityScoreBreakdownSeo(
                keyword_density = {
                    'key' : 1.337
                    },
                top_entities = {
                    'key' : [
                        wordlift_client.models.content_evaluation_response_quality_score_breakdown_seo_top_entities_value_inner.ContentEvaluationResponse_quality_score_breakdown_seo_top_entities_value_inner(
                            text = '', 
                            count = 56, )
                        ]
                    },
                score = 56,
        )
        """

    def testContentEvaluationResponseQualityScoreBreakdownSeo(self):
        """Test ContentEvaluationResponseQualityScoreBreakdownSeo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
